---------------------------
-- Computation for Lemma 2.2: case of 4 lines in PP^4
---------------------------

FF = QQ 

-- space of 5 x 3 matrices
M5x3 = FF[z_(0,0), z_(0,1), z_(0,2),
          z_(1,0), z_(1,1), z_(1,2),
          z_(2,0), z_(2,1), z_(2,2),
          z_(3,0), z_(3,1), z_(3,2),
          z_(4,0), z_(4,1), z_(4,2)]
-- rows
r0 = matrix {{z_(0,0), z_(0,1), z_(0,2)}}
r1 = matrix {{z_(1,0), z_(1,1), z_(1,2)}}
r2 = matrix {{z_(2,0), z_(2,1), z_(2,2)}}
r3 = matrix {{z_(3,0), z_(3,1), z_(3,2)}}
r4 = matrix {{z_(4,0), z_(4,1), z_(4,2)}}

-- ambient projective space of GG(2, 4) = G(3, 5)
PP9 = FF[M_(0,1,2),
         M_(0,1,3),
         M_(0,1,4),
         M_(0,2,3),
         M_(0,2,4),
         M_(0,3,4),
         M_(1,2,3),
         M_(1,2,4),
         M_(1,3,4),
         M_(2,3,4)]

-- Plücker relations
Pl = saturate kernel map (M5x3, PP9, {det (r0 || r1 || r2),
                                      det (r0 || r1 || r3),
                                      det (r0 || r1 || r4),
                                      det (r0 || r2 || r3),
                                      det (r0 || r2 || r4),
                                      det (r0 || r3 || r4),
                                      det (r1 || r2 || r3),
                                      det (r1 || r2 || r4),
                                      det (r1 || r3 || r4),
                                      det (r2 || r3 || r4)})

-- ideal of the Schubert variety of codim-2 planes
-- intersecting a line given by a 5x2 matrix with rows si
sch = (s0, s1, s2, s3, s4) -> (
  -- a plane P intersects a line L precisely if det (L | P) = 0
  ideal (  det (s0 || s1) * M_(2,3,4) -- computing det(L | P) in terms of Pl\"ucker coordinates of P
         - det (s0 || s2) * M_(1,3,4)
         + det (s0 || s3) * M_(1,2,4)
         - det (s0 || s4) * M_(1,2,3)
         + det (s1 || s2) * M_(0,3,4)
         - det (s1 || s3) * M_(0,2,4)
         + det (s1 || s4) * M_(0,2,3)
         + det (s2 || s3) * M_(0,1,4) 
         - det (s2 || s4) * M_(0,1,3)
         + det (s3 || s4) * M_(0,1,2))
)

-----------------------------------------------------------------------------------------------------
-- determine whether the subscheme of GG(2, 4) parametrising codim-2 planes touching 4 given lines
-- is integral and nonsingular, then print its dimension and degree
-----------------------------------------------------------------------------------------------------

S1 = sch (matrix {{1, 0}}, matrix {{0, 1}}, matrix {{0, 0}}, matrix {{0, 0}}, matrix {{0, 0}}) 
S2 = sch (matrix {{0, 0}}, matrix {{0, 0}}, matrix {{1, 0}}, matrix {{0, 1}}, matrix {{0, 0}})
S3 = sch (matrix {{1, 0}}, matrix {{1, 0}}, matrix {{1, 0}}, matrix {{1, 0}}, matrix {{0, 1}})
S4 = sch (matrix {{2, 5}}, matrix {{4, 3}}, matrix {{11, 7}}, matrix {{8, 9}}, matrix {{10, 13}}) --- a line in "sufficiently general position" with respect to the others 

Lambda = Pl+S1+S2+S3+S4
D = 6 - codim  (Pl + S1 + S2 + S3 + S4) + codim Pl


print "Output 1: Is the family of planes touching 4 chosen lines irreducible?"; print isPrime Lambda;

print "Output 2: Dimension of the family:"; print D;