---------------------------
-- Computation for Lemma 2.2: case of 5 lines in PP^5
---------------------------

FF = QQ

-- space of 6 x 4 matrices
M6x4 = FF[z_(0,0), z_(0,1), z_(0,2), z_(0,3),
          z_(1,0), z_(1,1), z_(1,2), z_(1,3),
          z_(2,0), z_(2,1), z_(2,2), z_(2,3),
          z_(3,0), z_(3,1), z_(3,2), z_(3,3),
          z_(4,0), z_(4,1), z_(4,2), z_(4,3),
          z_(5,0), z_(5,1), z_(5,2), z_(5,3)]
-- rows
r0 = matrix {{z_(0,0), z_(0,1), z_(0,2), z_(0,3)}}
r1 = matrix {{z_(1,0), z_(1,1), z_(1,2), z_(1,3)}}
r2 = matrix {{z_(2,0), z_(2,1), z_(2,2), z_(2,3)}}
r3 = matrix {{z_(3,0), z_(3,1), z_(3,2), z_(3,3)}}
r4 = matrix {{z_(4,0), z_(4,1), z_(4,2), z_(4,3)}}
r5 = matrix {{z_(5,0), z_(5,1), z_(5,2), z_(5,3)}}

-- projective ambient space of GG(3, 5) = G(4, 6)
PP15 = FF[M_(0,1,2,3),
          M_(0,1,2,4),
          M_(0,1,2,5),
          M_(0,1,3,4),
          M_(0,1,3,5),
          M_(0,1,4,5),
          M_(0,2,3,4),
          M_(0,2,3,5),
          M_(0,2,4,5),
          M_(0,3,4,5),
          M_(1,2,3,4),
          M_(1,2,3,5),
          M_(1,2,4,5),
          M_(1,3,4,5),
          M_(2,3,4,5)]

-- Plücker relations
Pl = saturate kernel map (M6x4, PP15, {det (r0 || r1 || r2 || r3),
                                       det (r0 || r1 || r2 || r4),
                                       det (r0 || r1 || r2 || r5),
                                       det (r0 || r1 || r3 || r4),
                                       det (r0 || r1 || r3 || r5),
                                       det (r0 || r1 || r4 || r5),
                                       det (r0 || r2 || r3 || r4),
                                       det (r0 || r2 || r3 || r5),
                                       det (r0 || r2 || r4 || r5),
                                       det (r0 || r3 || r4 || r5),
                                       det (r1 || r2 || r3 || r4),
                                       det (r1 || r2 || r3 || r5),
                                       det (r1 || r2 || r4 || r5),
                                       det (r1 || r3 || r4 || r5),
                                       det (r2 || r3 || r4 || r5)})

-- ideal of the Schubert variety of codim-2 planes
-- intersecting a line given by a 6x2 matrix with rows si
sch = (s0, s1, s2, s3, s4, s5) -> (
  -- a codim 2-plane P intersects a line L precisely if det (L | P) = 0
  ideal (  det (s0 || s1) * M_(2,3,4,5) -- computing det(L | P) in terms of Pl\"ucker coordinates of P
         - det (s0 || s2) * M_(1,3,4,5)
         + det (s0 || s3) * M_(1,2,4,5)
         - det (s0 || s4) * M_(1,2,3,5)
         + det (s0 || s5) * M_(1,2,3,4)
         + det (s1 || s2) * M_(0,3,4,5) 
         - det (s1 || s3) * M_(0,2,4,5)
         + det (s1 || s4) * M_(0,2,3,5)
         - det (s1 || s5) * M_(0,2,3,4)
         + det (s2 || s3) * M_(0,1,4,5)
         - det (s2 || s4) * M_(0,1,3,5)
         + det (s2 || s5) * M_(0,1,3,4)
         + det (s3 || s4) * M_(0,1,2,5) 
         - det (s3 || s5) * M_(0,1,2,4)
         + det (s4 || s5) * M_(0,1,2,3))
)

-----------------------------------------------------------------------------------------------------
-- determine whether the subscheme of GG(2, 5) parametrising codim-2 planes touching 5 given lines
-- is integral, and print its dimension
-----------------------------------------------------------------------------------------------------


S1 = sch (matrix {{1, 0}}, matrix {{0, 1}}, matrix {{0, 0}}, matrix {{0, 0}}, matrix {{0, 0}}, matrix {{0, 0}})
S2 = sch (matrix {{0, 0}}, matrix {{0, 0}}, matrix {{1, 0}}, matrix {{0, 1}}, matrix {{0, 0}}, matrix {{0, 0}})
S3 = sch (matrix {{0, 0}}, matrix {{0, 0}}, matrix {{0, 0}}, matrix {{0, 0}}, matrix {{1, 0}}, matrix {{0, 1}})
S4 = sch (matrix {{0, 1}}, matrix {{1, 1}}, matrix {{1, 1}}, matrix {{1, 1}}, matrix {{0, 1}}, matrix {{1, 1}})
S5 = sch (matrix {{1, 0}}, matrix {{0, 1}}, matrix {{1, 0}}, matrix {{1, 1}}, matrix {{1, 1}}, matrix {{1, 0}})


Lambda = Pl+S1+S2+S3+S4+S5
D = 8 - codim Lambda + codim Pl

print "Output 1: Is the family of planes touching 5 chosen lines irreducible?"; print isPrime Lambda;

print "Output 2: Dimension of the family:"; print D;
